@@ -42,6 +42,9 @@ class Element(ABC):
     def dump(self, dumper: nip.dumper.Dumper):
         return self.value.dump(dumper)
 
+    def __eq__(self, other):
+        return self.name == other.name and self.value == other.value
+
 
 class Document(Element):  # ToDo: add multi document support
     @classmethod
@@ -52,7 +55,7 @@ class Document(Element):  # ToDo: add multi document support
 
     @classmethod
     def _read_name(cls, stream: nip.stream.Stream):
-        read_tokens = stream.peek(tokens.Operator('---'), tokens.String) or \
+        read_tokens = stream.peek(tokens.Operator('---'), tokens.Name) or \
                       stream.peek(tokens.Operator('---'))
         if read_tokens is not None:
             stream.step()
@@ -121,14 +124,17 @@ class LinkCreation(Element):
     def read(cls, stream: nip.stream.Stream, parser: nip.parser.Parser) -> Union[Element, None]:
         read_tokens = stream.peek(tokens.Operator('&'), tokens.Name)
         if read_tokens is None:
+            # if stream.peek(tokens.Operator('&')):  # mb: do it more certainly: peak operator
+            #     raise nip.parser.ParserError(      # mb: firstly and then choose class to read)
+            #         stream, "Found variable creation operator '&' but name is not specified")
             return None
-        # if not isinstance(stream[1], tokens.Name):
-        #     raise nip.parser.ParserError(stream, "Wrong var creation")  # mb: No good errors now =(
 
         name = read_tokens[1].value
         stream.step()
 
         value = RightValue.read(stream, parser)
+        if name in parser.links:
+            raise nip.parser.ParserError(f"Redefining of link '{name}'")
         parser.links.append(name)
 
         return LinkCreation(name, value)
@@ -265,7 +271,9 @@ class Args(Element):
     @classmethod
     def _read_dict_pair(cls, stream: nip.stream.Stream, parser: nip.parser.Parser) \
             -> Union[Tuple[str, Element], Tuple[None, None]]:
-        read_tokens = stream.peek(tokens.String, tokens.Operator(': '))
+        # mb: read String instead of Name for keys with spaces,
+        # mb: but this leads to the case that
+        read_tokens = stream.peek(tokens.Name, tokens.Operator(': '))
         if read_tokens is None:
             return None, None
 
@@ -411,7 +419,7 @@ class Nothing(Element):
             return Nothing()
 
     def construct(self, constructor: nip.constructor.Constructor):
-        return Nothing
+        return self
 
     def dump(self, dumper: nip.dumper.Dumper):
         return ""
